summaryrefslogtreecommitdiff
path: root/src/compiler/scala/tools/nsc/ast/parser/BracePair.scala
diff options
context:
space:
mode:
authorMartin Odersky <odersky@gmail.com>2009-08-16 16:29:36 +0000
committerMartin Odersky <odersky@gmail.com>2009-08-16 16:29:36 +0000
commit110b737f99c4e4850f9a0f861db6b9f831ae056e (patch)
tree35db6883632ffdef4c49f0699cf330f9526ce6c9 /src/compiler/scala/tools/nsc/ast/parser/BracePair.scala
parentfe72ad6351aa3e06c894972e959fa768ed60a515 (diff)
downloadscala-110b737f99c4e4850f9a0f861db6b9f831ae056e.tar.gz
scala-110b737f99c4e4850f9a0f861db6b9f831ae056e.tar.bz2
scala-110b737f99c4e4850f9a0f861db6b9f831ae056e.zip
1.
2. Relaxed bounds checking rules for existential types.
Diffstat (limited to 'src/compiler/scala/tools/nsc/ast/parser/BracePair.scala')
-rw-r--r--src/compiler/scala/tools/nsc/ast/parser/BracePair.scala10
1 files changed, 7 insertions, 3 deletions
diff --git a/src/compiler/scala/tools/nsc/ast/parser/BracePair.scala b/src/compiler/scala/tools/nsc/ast/parser/BracePair.scala
index ea64eee7ba..11d6c997c1 100644
--- a/src/compiler/scala/tools/nsc/ast/parser/BracePair.scala
+++ b/src/compiler/scala/tools/nsc/ast/parser/BracePair.scala
@@ -6,8 +6,12 @@ package scala.tools.nsc
package ast.parser
/** A descriptor for a matching pair of braces.
* @param loff The offset of the opening brace (-1 means missing)
* @param roff The offset of the closing brace (-1 means missing)
* @param nested The brace pairs nested in this one
*/
-case class BracePair(loff: Int, off: Int, nested: List[BracePair])
+case class BracePair(loff: Int, lindent: Int, roff: Int, rindent: Int, nested: List[BracePair])
+
+
@@ -6,8 +6,12 @@ package scala.tools.nsc
package ast.parser
/** A descriptor for a matching pair of braces.
- * @param loff The offset of the opening brace (-1 means missing)
- * @param roff The offset of the closing brace (-1 means missing)
+ * @param loff The offset of the opening brace (-1 means missing)
+ * @param lindent The indentation depth of the line of the opening brace (-1 means missing)
+ * @param roff The offset of the closing brace (-1 means missing)
+ * @param rindent The indentation depth of the line of the closing brace (-1 means missing)
* @param nested The brace pairs nested in this one
*/